# 参考

- [面向下一代Web的深度学习编译：WebAssembly和WebGPU初探](https://zhuanlan.zhihu.com/p/141008345)
- [PyTorch全新性能分析工具，可视化瓶颈，并集成到了VS Code](https://zhuanlan.zhihu.com/p/360479566)
- [FFI Navigator: 跨语言调用跳转IDE插件](https://zhuanlan.zhihu.com/p/103426525)
- [LSP-language-server-protocol规范学](https://zhuanlan.zhihu.com/p/343218679)
- [语言服务器协议](https://docs.microsoft.com/zh-cn/visualstudio/extensibility/language-server-protocol?view=vs-2022)

FFI
:   全称 Foreign Function Interface。它用一种编程语言写的程序能调用另一种编程语言写的函数（routines）。